@@ -1,4 +1,4 @@
-/* $Id: gucharmap-chapters.c 1493 2007-12-12 19:33:26Z chpe $ */
+/* $Id: gucharmap-chapters.c 1537 2008-01-25 22:05:40Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  * Copyright (C) 2007 Christian Persch
@@ -15,13 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
+ * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
 #include "config.h"
 #include "gucharmap-chapters.h"
 #include "gucharmap-chapters-model.h"
 #include "gucharmap-chapters-view.h"
+#include "gucharmap-settings.h"
 #include "gucharmap-marshal.h"
 #include "gucharmap-intl.h"
 #include <string.h>
@@ -114,6 +115,7 @@ gucharmap_chapters_constructor (GType type,
   gtk_container_add (GTK_CONTAINER (chapters), chapters->tree_view);
   gtk_widget_show (chapters->tree_view);
 
+  gucharmap_chapters_go_to_character (chapters, gucharmap_settings_get_last_char ());
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (chapters->tree_view));
   g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), chapters);
     
