@@ -1,4 +1,4 @@
-/* $Id: gucharmap-table.h 1356 2007-09-05 05:53:42Z behdad $ */
+/* $Id: gucharmap-table.h 1391 2007-12-05 23:40:40Z chpe $ */
 /*
  * Copyright (c) 2004 Noah Levitt
  *
@@ -59,7 +59,7 @@ struct _GucharmapTable
   GtkWidget *scrollbar;
 
   GtkWidget *zoom_window;
-  GdkPixmap *zoom_pixmap;
+  GtkWidget *zoom_image;
   gboolean zoom_mode_enabled;
 
   gboolean snap_pow2_enabled;
@@ -91,8 +91,6 @@ void gucharmap_table_set_active_character (GucharmapTable *chartable,
                                            gunichar uc);
 void gucharmap_table_zoom_enable (GucharmapTable *chartable);
 void gucharmap_table_zoom_disable (GucharmapTable *chartable);
-void gucharmap_table_identify_clipboard (GucharmapTable *chartable, 
-                                         GtkClipboard *clipboard);
 void gucharmap_table_grab_focus (GucharmapTable *chartable);
 void gucharmap_table_set_snap_pow2 (GucharmapTable *chartable, 
                                     gboolean snap);
